aboutsummaryrefslogtreecommitdiff
path: root/examples/graph_googlenet.cpp
diff options
context:
space:
mode:
authorIsabella Gottardi <isabella.gottardi@arm.com>2017-11-03 12:11:55 +0000
committerAnthony Barbier <anthony.barbier@arm.com>2018-11-02 16:35:24 +0000
commita4c6188262d6d9f75f019e437f8190bdd56e604d (patch)
tree6abdf95cea0e1bdffca342386f899734604cc992 /examples/graph_googlenet.cpp
parentd621bca4e963555a99be4328c8d49d1813789649 (diff)
downloadComputeLibrary-a4c6188262d6d9f75f019e437f8190bdd56e604d.tar.gz
COMPMID-657 - Add PPMAccessor and TopNPredictionsAccessor to GoogleNet
Change-Id: Ib6f2f9e73043d2c59b2698c243fb1a9f51c526e9 Reviewed-on: http://mpd-gerrit.cambridge.arm.com/94363 Tested-by: Kaizen <jeremy.johnson+kaizengerrit@arm.com> Reviewed-by: Gian Marco Iodice <gianmarco.iodice@arm.com>
Diffstat (limited to 'examples/graph_googlenet.cpp')
-rw-r--r--examples/graph_googlenet.cpp96
1 files changed, 44 insertions, 52 deletions
diff --git a/examples/graph_googlenet.cpp b/examples/graph_googlenet.cpp
index 0e82c1e85d..354a2a39e4 100644
--- a/examples/graph_googlenet.cpp
+++ b/examples/graph_googlenet.cpp
@@ -42,27 +42,6 @@
using namespace arm_compute::graph;
using namespace arm_compute::graph_utils;
-/** Generates appropriate accessor according to the specified path
- *
- * @note If path is empty will generate a DummyAccessor else will generate a NumPyBinLoader
- *
- * @param path Path to the data files
- * @param data_file Relative path to the data files from path
- *
- * @return An appropriate tensor accessor
- */
-std::unique_ptr<ITensorAccessor> get_accessor(const std::string &path, const std::string &data_file)
-{
- if(path.empty())
- {
- return arm_compute::support::cpp14::make_unique<DummyAccessor>();
- }
- else
- {
- return arm_compute::support::cpp14::make_unique<NumPyBinLoader>(path + data_file);
- }
-}
-
BranchLayer get_inception_node(const std::string &data_path, std::string &&param_path,
unsigned int a_filt,
std::tuple<unsigned int, unsigned int> b_filters,
@@ -73,36 +52,36 @@ BranchLayer get_inception_node(const std::string &data_path, std::string &&param
SubGraph i_a;
i_a << ConvolutionLayer(
1U, 1U, a_filt,
- get_accessor(data_path, total_path + "1x1_w.npy"),
- get_accessor(data_path, total_path + "1x1_b.npy"),
+ get_weights_accessor(data_path, total_path + "1x1_w.npy"),
+ get_weights_accessor(data_path, total_path + "1x1_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
SubGraph i_b;
i_b << ConvolutionLayer(
1U, 1U, std::get<0>(b_filters),
- get_accessor(data_path, total_path + "3x3_reduce_w.npy"),
- get_accessor(data_path, total_path + "3x3_reduce_b.npy"),
+ get_weights_accessor(data_path, total_path + "3x3_reduce_w.npy"),
+ get_weights_accessor(data_path, total_path + "3x3_reduce_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< ConvolutionLayer(
3U, 3U, std::get<1>(b_filters),
- get_accessor(data_path, total_path + "3x3_w.npy"),
- get_accessor(data_path, total_path + "3x3_b.npy"),
+ get_weights_accessor(data_path, total_path + "3x3_w.npy"),
+ get_weights_accessor(data_path, total_path + "3x3_b.npy"),
PadStrideInfo(1, 1, 1, 1))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
SubGraph i_c;
i_c << ConvolutionLayer(
1U, 1U, std::get<0>(c_filters),
- get_accessor(data_path, total_path + "5x5_reduce_w.npy"),
- get_accessor(data_path, total_path + "5x5_reduce_b.npy"),
+ get_weights_accessor(data_path, total_path + "5x5_reduce_w.npy"),
+ get_weights_accessor(data_path, total_path + "5x5_reduce_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< ConvolutionLayer(
5U, 5U, std::get<1>(c_filters),
- get_accessor(data_path, total_path + "5x5_w.npy"),
- get_accessor(data_path, total_path + "5x5_b.npy"),
+ get_weights_accessor(data_path, total_path + "5x5_w.npy"),
+ get_weights_accessor(data_path, total_path + "5x5_b.npy"),
PadStrideInfo(1, 1, 2, 2))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
@@ -110,8 +89,8 @@ BranchLayer get_inception_node(const std::string &data_path, std::string &&param
i_d << PoolingLayer(PoolingLayerInfo(PoolingType::MAX, 3, PadStrideInfo(1, 1, 1, 1, DimensionRoundingType::CEIL)))
<< ConvolutionLayer(
1U, 1U, d_filt,
- get_accessor(data_path, total_path + "pool_proj_w.npy"),
- get_accessor(data_path, total_path + "pool_proj_b.npy"),
+ get_weights_accessor(data_path, total_path + "pool_proj_w.npy"),
+ get_weights_accessor(data_path, total_path + "pool_proj_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU));
@@ -121,32 +100,44 @@ BranchLayer get_inception_node(const std::string &data_path, std::string &&param
/** Example demonstrating how to implement Googlenet's network using the Compute Library's graph API
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
*/
void main_graph_googlenet(int argc, const char **argv)
{
- std::string data_path; /** Path to the trainable data */
- unsigned int batches = 4; /** Number of batches */
+ std::string data_path; /* Path to the trainable data */
+ std::string image; /* Image data */
+ std::string label; /* Label data */
+
+ constexpr float mean_r = 122.68f; /* Mean value to subtract from red channel */
+ constexpr float mean_g = 116.67f; /* Mean value to subtract from green channel */
+ constexpr float mean_b = 104.01f; /* Mean value to subtract from blue channel */
// Parse arguments
if(argc < 2)
{
// Print help
- std::cout << "Usage: " << argv[0] << " [path_to_data] [batches]\n\n";
+ std::cout << "Usage: " << argv[0] << " [path_to_data] [image] [labels]\n\n";
std::cout << "No data folder provided: using random values\n\n";
}
else if(argc == 2)
{
//Do something with argv[1]
data_path = argv[1];
- std::cout << "Usage: " << argv[0] << " [path_to_data] [batches]\n\n";
- std::cout << "No number of batches where specified, thus will use the default : " << batches << "\n\n";
+ std::cout << "Usage: " << argv[0] << " " << argv[1] << " [image] [labels]\n\n";
+ std::cout << "No image provided: using random values\n";
+ }
+ else if(argc == 3)
+ {
+ data_path = argv[1];
+ image = argv[2];
+ std::cout << "Usage: " << argv[0] << " " << argv[1] << " " << argv[2] << " [labels]\n\n";
+ std::cout << "No text file with labels provided: skipping output accessor\n";
}
else
{
- //Do something with argv[1] and argv[2]
data_path = argv[1];
- batches = std::strtol(argv[2], nullptr, 0);
+ image = argv[2];
+ label = argv[3];
}
// Check if OpenCL is available and initialize the scheduler
@@ -158,25 +149,26 @@ void main_graph_googlenet(int argc, const char **argv)
Graph graph;
graph << TargetHint::OPENCL
- << Tensor(TensorInfo(TensorShape(224U, 224U, 3U, batches), 1, DataType::F32), DummyAccessor())
+ << Tensor(TensorInfo(TensorShape(224U, 224U, 3U, 1U), 1, DataType::F32),
+ get_input_accessor(image, mean_r, mean_g, mean_b))
<< ConvolutionLayer(
7U, 7U, 64U,
- get_accessor(data_path, "/cnn_data/googlenet_model/conv1/conv1_7x7_s2_w.npy"),
- get_accessor(data_path, "/cnn_data/googlenet_model/conv1/conv1_7x7_s2_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv1/conv1_7x7_s2_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv1/conv1_7x7_s2_b.npy"),
PadStrideInfo(2, 2, 3, 3))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< PoolingLayer(PoolingLayerInfo(PoolingType::MAX, 3, PadStrideInfo(2, 2, 0, 0, DimensionRoundingType::CEIL)))
<< NormalizationLayer(NormalizationLayerInfo(NormType::CROSS_MAP, 5, 0.0001f, 0.75f))
<< ConvolutionLayer(
1U, 1U, 64U,
- get_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_reduce_w.npy"),
- get_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_reduce_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_reduce_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_reduce_b.npy"),
PadStrideInfo(1, 1, 0, 0))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< ConvolutionLayer(
3U, 3U, 192U,
- get_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_w.npy"),
- get_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_b.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/conv2/conv2_3x3_b.npy"),
PadStrideInfo(1, 1, 1, 1))
<< ActivationLayer(ActivationLayerInfo(ActivationLayerInfo::ActivationFunction::RELU))
<< NormalizationLayer(NormalizationLayerInfo(NormType::CROSS_MAP, 5, 0.0001f, 0.75f))
@@ -195,10 +187,10 @@ void main_graph_googlenet(int argc, const char **argv)
<< PoolingLayer(PoolingLayerInfo(PoolingType::AVG, 7, PadStrideInfo(1, 1, 0, 0, DimensionRoundingType::CEIL)))
<< FullyConnectedLayer(
1000U,
- get_accessor(data_path, "/cnn_data/googlenet_model/loss3/loss3_classifier_w.npy"),
- get_accessor(data_path, "/cnn_data/googlenet_model/loss3/loss3_classifier_b.npy"))
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/loss3/loss3_classifier_w.npy"),
+ get_weights_accessor(data_path, "/cnn_data/googlenet_model/loss3/loss3_classifier_b.npy"))
<< SoftmaxLayer()
- << Tensor(DummyAccessor());
+ << Tensor(get_output_accessor(label, 5));
graph.run();
}
@@ -206,7 +198,7 @@ void main_graph_googlenet(int argc, const char **argv)
/** Main program for Googlenet
*
* @param[in] argc Number of arguments
* @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
*/
int main(int argc, const char **argv)
{
@@ -121,32 +100,44 @@ BranchLayer get_inception_node(const std::string &data_path, std::string &&param
*
* @param[in] argc Number of arguments
- * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
+ * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] image, [optional] labels )
*/
void main_graph_googlenet(int argc, const char **argv)
@@ -206,7 +198,7 @@ void main_graph_googlenet(int argc, const char **argv)
*
* @param[in] argc Number of arguments
- * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] batches )
+ * @param[in] argv Arguments ( [optional] Path to the weights folder, [optional] image, [optional] labels )
*/
int main(int argc, const char **argv)